You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by vm...@apache.org on 2012/12/27 03:50:50 UTC

svn commit: r1426105 - in /subversion/branches/javahl-ra: ./ subversion/ subversion/include/ subversion/libsvn_client/ subversion/libsvn_fs_fs/ subversion/libsvn_ra_serf/ subversion/libsvn_ra_svn/ subversion/libsvn_subr/ subversion/svn/ subversion/svna...

Author: vmpn
Date: Thu Dec 27 02:50:50 2012
New Revision: 1426105

URL: http://svn.apache.org/viewvc?rev=1426105&view=rev
Log:
On the javahl-ra branch:

Bring up-to-date with trunk@1405871

Modified:
    subversion/branches/javahl-ra/   (props changed)
    subversion/branches/javahl-ra/configure.ac
    subversion/branches/javahl-ra/subversion/include/svn_error_codes.h
    subversion/branches/javahl-ra/subversion/include/svn_fs.h
    subversion/branches/javahl-ra/subversion/include/svn_props.h
    subversion/branches/javahl-ra/subversion/libsvn_client/add.c
    subversion/branches/javahl-ra/subversion/libsvn_client/client.h
    subversion/branches/javahl-ra/subversion/libsvn_client/commit.c
    subversion/branches/javahl-ra/subversion/libsvn_fs_fs/caching.c
    subversion/branches/javahl-ra/subversion/libsvn_ra_serf/ra_serf.h
    subversion/branches/javahl-ra/subversion/libsvn_ra_svn/ra_svn.h
    subversion/branches/javahl-ra/subversion/libsvn_subr/named_atomic.c
    subversion/branches/javahl-ra/subversion/svn/mergeinfo-cmd.c
    subversion/branches/javahl-ra/subversion/svn_private_config.hw
    subversion/branches/javahl-ra/subversion/svnadmin/main.c
    subversion/branches/javahl-ra/subversion/tests/cmdline/autoprop_tests.py
    subversion/branches/javahl-ra/subversion/tests/cmdline/externals_tests.py
    subversion/branches/javahl-ra/subversion/tests/cmdline/import_tests.py
    subversion/branches/javahl-ra/subversion/tests/cmdline/merge_tests.py
    subversion/branches/javahl-ra/subversion/tests/cmdline/mergeinfo_tests.py
    subversion/branches/javahl-ra/subversion/tests/cmdline/prop_tests.py
    subversion/branches/javahl-ra/subversion/tests/cmdline/svntest/main.py

Propchange: subversion/branches/javahl-ra/
------------------------------------------------------------------------------
  Merged /subversion/trunk:r1405540-1405871

Modified: subversion/branches/javahl-ra/configure.ac
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/configure.ac?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/configure.ac (original)
+++ subversion/branches/javahl-ra/configure.ac Thu Dec 27 02:50:50 2012
@@ -1393,6 +1393,10 @@ dnl Provide ${host} for use in compiled 
 AC_DEFINE_UNQUOTED([SVN_BUILD_HOST], "${host}",
                    [Defined to the config.guess name of the build system])
 
+dnl Provide ${target} for use in compiled code (for user-agent string)
+AC_DEFINE_UNQUOTED([SVN_BUILD_TARGET], "${target}",
+                   [Defined to the config.guess name of the build target])
+
 AC_OUTPUT
 
 # ==== Print final messages to user ==========================================

Modified: subversion/branches/javahl-ra/subversion/include/svn_error_codes.h
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/include/svn_error_codes.h?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/include/svn_error_codes.h (original)
+++ subversion/branches/javahl-ra/subversion/include/svn_error_codes.h Thu Dec 27 02:50:50 2012
@@ -1425,6 +1425,11 @@ SVN_ERROR_START
              SVN_ERR_MISC_CATEGORY_START + 37,
              "failed to parse version number string")
 
+  /** @since New in 1.8. */
+  SVN_ERRDEF(SVN_ERR_CORRUPTED_ATOMIC_STORAGE,
+             SVN_ERR_MISC_CATEGORY_START + 38,
+             "Atomic data storage is corrupt")
+
   /* command-line client errors */
 
   SVN_ERRDEF(SVN_ERR_CL_ARG_PARSING_ERROR,

Modified: subversion/branches/javahl-ra/subversion/include/svn_fs.h
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/include/svn_fs.h?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/include/svn_fs.h (original)
+++ subversion/branches/javahl-ra/subversion/include/svn_fs.h Thu Dec 27 02:50:50 2012
@@ -88,6 +88,10 @@ typedef struct svn_fs_t svn_fs_t;
 
 /** Enable / disable revprop caching for a FSFS repository.
  *
+ * "2" is allowed, too and means "enable if efficient",
+ * i.e. this will not create warning at runtime if there
+ * if no efficient support for revprop caching.
+ *
  * @since New in 1.8.
  */
 #define SVN_FS_CONFIG_FSFS_CACHE_REVPROPS       "fsfs-cache-revprops"

Modified: subversion/branches/javahl-ra/subversion/include/svn_props.h
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/include/svn_props.h?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/include/svn_props.h (original)
+++ subversion/branches/javahl-ra/subversion/include/svn_props.h Thu Dec 27 02:50:50 2012
@@ -384,14 +384,11 @@ svn_prop_name_is_valid(const char *prop_
  */
 #define SVN_PROP_MERGEINFO SVN_PROP_PREFIX "mergeinfo"
 
-/** Prefix for all Subersion inhertiable properties. */
-#define SVN_PROP_INHERITABLE_PREFIX SVN_PROP_PREFIX "inheritable-"
-
 /** Property used to record inheritable configuration auto-props. */
-#define SVN_PROP_INHERITABLE_AUTO_PROPS SVN_PROP_INHERITABLE_PREFIX "auto-props"
+#define SVN_PROP_INHERITABLE_AUTO_PROPS SVN_PROP_PREFIX "auto-props"
 
 /** Property used to record inheritable configuration ignores. */
-#define SVN_PROP_INHERITABLE_IGNORES SVN_PROP_INHERITABLE_PREFIX "ignores"
+#define SVN_PROP_INHERITABLE_IGNORES SVN_PROP_PREFIX "global-ignores"
 
 /** Meta-data properties.
  *

Modified: subversion/branches/javahl-ra/subversion/libsvn_client/add.c
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/libsvn_client/add.c?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/libsvn_client/add.c (original)
+++ subversion/branches/javahl-ra/subversion/libsvn_client/add.c Thu Dec 27 02:50:50 2012
@@ -292,7 +292,7 @@ add_file(const char *local_abspath,
       apr_hash_t *file_autoprops;
 
       /* Get automatic properties */
-      /* Grab the inherited svn:inheritable-auto-props and config file
+      /* Grab the inherited svn:auto-props and config file
          auto-props for this file if we haven't already got them
          when iterating over the file's unversioned parents. */
       if (autoprops == NULL)
@@ -380,12 +380,12 @@ add_file(const char *local_abspath,
  * if necessary.
  *
  * If not NULL, *CONFIG_AUTOPROPS is a hash representing the config file and
- * svn:inheritable-auto-props autoprops which apply to DIR_ABSPATH.  It maps
+ * svn:auto-props autoprops which apply to DIR_ABSPATH.  It maps
  * const char * file patterns to another hash which maps const char *
  * property names to const char *property values.  If *CONFIG_AUTOPROPS is
  * NULL and DIR_ABSPATH is unversioned, then this function will populate
  * *CONFIG_AUTOPROPS (allocated in RESULT_POOL) using DIR_ABSPATH's nearest
- * versioned parent to determine the svn:inheritable-auto-props which DIR_ABSPATH
+ * versioned parent to determine the svn:auto-props which DIR_ABSPATH
  * will inherit once added.
  *
  * If IGNORES is not NULL, then it is an array of const char * ignore patterns
@@ -452,9 +452,9 @@ add_dir_recursive(const char *dir_abspat
   /* For the root of any unversioned subtree, get some or all of the
      following:
 
-       1) Explicit and inherited svn:inheritable-auto-props properties on
+       1) Explicit and inherited svn:auto-props properties on
           DIR_ABSPATH
-       2) Explicit and inherited svn:inheritabled-ignores properties on
+       2) Explicit and inherited svn:global-ignores properties on
           DIR_ABSPATH
        3) auto-props from the CTX->CONFIG hash */
   if (!entry_exists && *config_autoprops == NULL)
@@ -537,7 +537,7 @@ add_dir_recursive(const char *dir_abspat
 }
 
 /* This structure is used as baton for collecting the config entries
-   in the auto-props section and any inherited svn:inheritable-auto-props
+   in the auto-props section and any inherited svn:auto-props
    properties.
 */
 typedef struct collect_auto_props_baton_t
@@ -702,7 +702,7 @@ svn_client__get_all_auto_props(apr_hash_
 
   /* Are "traditional" auto-props enabled?  If so grab them from the
     config.  This is our starting set auto-props, which may be overriden
-    by svn:inheritable-auto-props. */
+    by svn:auto-props. */
   SVN_ERR(svn_config_get_bool(cfg, &use_autoprops,
                               SVN_CONFIG_SECTION_MISCELLANY,
                               SVN_CONFIG_OPTION_ENABLE_AUTO_PROPS, FALSE));
@@ -781,7 +781,7 @@ svn_client__get_all_auto_props(apr_hash_
           config_auto_prop_pattern = svn_stringbuf_create_empty(iterpool);
           config_auto_prop_val = svn_stringbuf_create_empty(iterpool);
 
-          /* Parse svn:inheritable-auto-props value. */
+          /* Parse svn:auto-props value. */
           while (*ch != '\0')
             {
               svn_stringbuf_setempty(config_auto_prop_pattern);

Modified: subversion/branches/javahl-ra/subversion/libsvn_client/client.h
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/libsvn_client/client.h?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/libsvn_client/commit.c (original)
+++ subversion/branches/javahl-ra/subversion/libsvn_client/commit.c Thu Dec 27 02:50:50 2012
@@ -77,7 +77,7 @@ typedef struct import_ctx_t
   svn_magic__cookie_t *magic_cookie;
 
   /* Collection of all possible configuration file dictated auto-props and
-     svn:inheritable-auto-props.  A hash mapping const char * file patterns to a
+     svn:auto-props.  A hash mapping const char * file patterns to a
      second hash which maps const char * property names to const char *
      property values.  Properties which don't have a value, e.g. svn:executable,
      simply map the property name to an empty string. */
@@ -613,7 +613,7 @@ import_dir(const svn_delta_editor_t *edi
  * the import (values are unused).
  *
  * AUTOPROPS is hash of all config file autoprops and
- * svn:inheritable-auto-props inherited by the import target, see the
+ * svn:auto-props inherited by the import target, see the
  * IMPORT_CTX member of the same name.
  *
  * LOCAL_IGNORES is an array of const char * ignore patterns which
@@ -622,7 +622,7 @@ import_dir(const svn_delta_editor_t *edi
  * target should be ignored and not imported.
  *
  * MANDATORY_IGNORES is an array of const char * ignore patterns which
- * correspond to the svn:inheritable-ignores properties (if any) set on
+ * correspond to the svn:global-ignores properties (if any) set on
  * the root of the repository target or inherited by it.
  *
  * If NO_IGNORE is FALSE, don't import files or directories that match
@@ -1029,7 +1029,7 @@ svn_client_import5(const char *path,
                                     commit_baton, NULL, TRUE,
                                     scratch_pool));
 
-  /* Get inherited svn:inheritable-auto-props, svn:inheritable-ignores, and
+  /* Get inherited svn:auto-props, svn:global-ignores, and
      svn:ignores for the location we are importing to. */
   SVN_ERR(svn_client__get_all_auto_props(&autoprops, url, ctx,
                                          scratch_pool, iterpool));

Modified: subversion/branches/javahl-ra/subversion/libsvn_fs_fs/caching.c
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/libsvn_fs_fs/caching.c?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/libsvn_fs_fs/caching.c (original)
+++ subversion/branches/javahl-ra/subversion/libsvn_fs_fs/caching.c Thu Dec 27 02:50:50 2012
@@ -83,11 +83,19 @@ read_config(svn_memcache_t **memcache_p,
    * Revprop caching significantly speeds up operations like
    * svn ls -v. However, it requires synchronization that may
    * not be available or efficient in the current server setup.
+   * 
+   * If the caller chose option "2", enable revprop caching if
+   * the required API support is there to make it efficient.
    */
-  *cache_revprops
-    = svn_hash__get_bool(fs->config,
-                         SVN_FS_CONFIG_FSFS_CACHE_REVPROPS,
-                         FALSE);
+  if (strcmp(svn_hash__get_cstring(fs->config,
+                                   SVN_FS_CONFIG_FSFS_CACHE_REVPROPS,
+                                   ""), "2"))
+    *cache_revprops
+      = svn_hash__get_bool(fs->config,
+                          SVN_FS_CONFIG_FSFS_CACHE_REVPROPS,
+                          FALSE);
+  else
+    *cache_revprops = svn_named_atomic__is_efficient();
 
   return svn_config_get_bool(ffd->config, fail_stop,
                              CONFIG_SECTION_CACHES, CONFIG_OPTION_FAIL_STOP,

Modified: subversion/branches/javahl-ra/subversion/libsvn_ra_serf/ra_serf.h
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/libsvn_ra_serf/ra_serf.h?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/libsvn_ra_serf/ra_serf.h (original)
+++ subversion/branches/javahl-ra/subversion/libsvn_ra_serf/ra_serf.h Thu Dec 27 02:50:50 2012
@@ -57,7 +57,8 @@ extern "C" {
 #define UNUSED_CTX(x) ((void)(x))
 
 /** Our User-Agent string. */
-#define USER_AGENT "SVN/" SVN_VER_NUMBER " serf/" \
+#define USER_AGENT "SVN/" SVN_VER_NUMBER " (" SVN_BUILD_TARGET ")" \
+                   " serf/" \
                    APR_STRINGIFY(SERF_MAJOR_VERSION) "." \
                    APR_STRINGIFY(SERF_MINOR_VERSION) "." \
                    APR_STRINGIFY(SERF_PATCH_VERSION)

Modified: subversion/branches/javahl-ra/subversion/libsvn_ra_svn/ra_svn.h
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/libsvn_ra_svn/ra_svn.h?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/libsvn_ra_svn/ra_svn.h (original)
+++ subversion/branches/javahl-ra/subversion/libsvn_ra_svn/ra_svn.h Thu Dec 27 02:50:50 2012
@@ -57,7 +57,8 @@ typedef svn_error_t *(*ra_svn_block_hand
                                                void *baton);
 
 /* The default "user agent". */
-#define SVN_RA_SVN__DEFAULT_USERAGENT  "SVN/" SVN_VER_NUMBER
+#define SVN_RA_SVN__DEFAULT_USERAGENT  "SVN/" SVN_VER_NUMBER\
+                                       " (" SVN_BUILD_TARGET ")"
 
 /* The size of our per-connection read and write buffers. */
 #define SVN_RA_SVN__PAGE_SIZE 4096

Modified: subversion/branches/javahl-ra/subversion/libsvn_subr/named_atomic.c
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/libsvn_subr/named_atomic.c?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/libsvn_subr/named_atomic.c (original)
+++ subversion/branches/javahl-ra/subversion/libsvn_subr/named_atomic.c Thu Dec 27 02:50:50 2012
@@ -462,10 +462,12 @@ svn_atomic_namespace__create(svn_atomic_
 
   if (!err && new_ns->data)
     {
-      /* Sanitize (in case of data corruption)
+      /* Detect severe cases of corruption (i.e. when some outsider messed
+       * with our data file)
        */
       if (new_ns->data->count > MAX_ATOMIC_COUNT)
-        new_ns->data->count = MAX_ATOMIC_COUNT;
+        return svn_error_create(SVN_ERR_CORRUPTED_ATOMIC_STORAGE, 0,
+                       _("Number of atomics in namespace is too large."));
 
       /* Cache the number of existing, complete entries.  There can't be
        * incomplete ones from other processes because we hold the mutex.

Modified: subversion/branches/javahl-ra/subversion/svn/mergeinfo-cmd.c
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/svn/mergeinfo-cmd.c?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/svn/mergeinfo-cmd.c (original)
+++ subversion/branches/javahl-ra/subversion/svn/mergeinfo-cmd.c Thu Dec 27 02:50:50 2012
@@ -152,7 +152,7 @@ mergeinfo_diagram(svn_client__pathrev_t 
       col_width[col] = 0;
       for (row = 0; row < ROWS; row++)
         {
-          if (g[row][col] && (strlen(g[row][col]) > col_width[col]))
+          if (g[row][col] && ((int)strlen(g[row][col]) > col_width[col]))
             col_width[col] = (int)strlen(g[row][col]);
         }
     }

Modified: subversion/branches/javahl-ra/subversion/svn_private_config.hw
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/svn_private_config.hw?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/svn_private_config.hw (original)
+++ subversion/branches/javahl-ra/subversion/svn_private_config.hw Thu Dec 27 02:50:50 2012
@@ -33,6 +33,16 @@
 /* Define to a Windows-specific equivalent of config.guess output */
 #define SVN_BUILD_HOST "x86-microsoft-windows"
 
+#if defined(_M_X64)
+#define SVN_BUILD_TARGET "x64-microsoft-windows"
+#elif defined(_M_IA64)
+#define SVN_BUILD_TARGET "ia64-microsoft-windows"
+#elif defined( _M_IX86)
+#define SVN_BUILD_TARGET "x86-microsoft-windows"
+#else
+#error Unsupported build target.
+#endif
+
 /* The minimal version of Berkeley DB we want */
 #define SVN_FS_WANT_DB_MAJOR    4
 #define SVN_FS_WANT_DB_MINOR    0

Modified: subversion/branches/javahl-ra/subversion/svnadmin/main.c
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/svnadmin/main.c?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/svnadmin/main.c (original)
+++ subversion/branches/javahl-ra/subversion/svnadmin/main.c Thu Dec 27 02:50:50 2012
@@ -43,7 +43,6 @@
 #include "svn_xml.h"
 
 #include "private/svn_opt_private.h"
-#include "private/svn_named_atomic.h"
 
 #include "svn_private_config.h"
 
@@ -116,8 +115,7 @@ open_repos(svn_repos_t **repos,
   apr_hash_set(fs_config, SVN_FS_CONFIG_FSFS_CACHE_FULLTEXTS,
                APR_HASH_KEY_STRING, "1");
   apr_hash_set(fs_config, SVN_FS_CONFIG_FSFS_CACHE_REVPROPS,
-               APR_HASH_KEY_STRING,
-               svn_named_atomic__is_efficient() ? "1" : "0");
+               APR_HASH_KEY_STRING, "2");
 
   /* now, open the requested repository */
   SVN_ERR(svn_repos_open2(repos, path, fs_config, pool));

Modified: subversion/branches/javahl-ra/subversion/tests/cmdline/autoprop_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/tests/cmdline/autoprop_tests.py?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/tests/cmdline/autoprop_tests.py (original)
+++ subversion/branches/javahl-ra/subversion/tests/cmdline/autoprop_tests.py Thu Dec 27 02:50:50 2012
@@ -385,7 +385,7 @@ def check_inheritable_autoprops(sbox, au
 #----------------------------------------------------------------------
 def inheritable_autoprops_test(sbox, cmd, cfgenable, clienable, subdir,
                                do_import_or_add=True):
-  """configurable autoprops and svn:inheritable-auto-props test.
+  """configurable autoprops and svn:auto-props test.
 
      CMD is the subcommand to test: 'import' or 'add'
      if CFGENABLE is true, enable autoprops in the config file, else disable
@@ -438,7 +438,7 @@ def inheritable_autoprops_test(sbox, cmd
   else:
     files_wc_dir = wc_dir
 
-  # Set differing svn:inheritable-auto-props properties on various
+  # Set differing svn:auto-props properties on various
   # directories.
   sbox.simple_propset(SVN_PROP_INHERITABLE_AUTOPROPS,
                       '*.c = svn:eol-style=CRLF\n'
@@ -590,10 +590,10 @@ def svn_prop_inheritable_autoprops_imp_y
   inheritable_autoprops_test(sbox, 'import', 1, -1, '')
 
 #----------------------------------------------------------------------
-# Test svn:inheritable-auto-props when 'svn add' targets an already versioned
+# Test svn:auto-props when 'svn add' targets an already versioned
 # target.
 def svn_prop_inheritable_autoprops_add_versioned_target(sbox):
-  "svn:inheritable-auto-props and versioned target"
+  "svn:auto-props and versioned target"
 
   config_dir = inheritable_autoprops_test(sbox, 'add', 1, 0, '', False)
 
@@ -612,9 +612,9 @@ def svn_prop_inheritable_autoprops_add_v
   check_inheritable_autoprops(sbox, True)
 
 #----------------------------------------------------------------------
-# Can't set svn:inheritable-auto-props on files.
+# Can't set svn:auto-props on files.
 def svn_prop_inheritable_autoprops_propset_file_target(sbox):
-  "svn:inheritable-auto-props can't be set on files"
+  "svn:auto-props can't be set on files"
 
   sbox.build()
   svntest.actions.run_and_verify_svn(
@@ -634,7 +634,7 @@ def svn_prop_inheritable_autoprops_unver
   foo_path = sbox.ospath('A/D/Z/foo.c')
   bar_path = sbox.ospath('A/B/Y/bar.c')
 
-  # Set svn:inheritable-auto-props properties on two directories.
+  # Set svn:auto-props properties on two directories.
   svntest.main.run_svn(None, 'ps', SVN_PROP_INHERITABLE_AUTOPROPS,
                        '*.c=svn:eol-style=CR', sbox.ospath('A/B'))
   svntest.main.run_svn(None, 'ps', SVN_PROP_INHERITABLE_AUTOPROPS,

Modified: subversion/branches/javahl-ra/subversion/tests/cmdline/externals_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/tests/cmdline/externals_tests.py?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/tests/cmdline/externals_tests.py (original)
+++ subversion/branches/javahl-ra/subversion/tests/cmdline/externals_tests.py Thu Dec 27 02:50:50 2012
@@ -2671,6 +2671,18 @@ def include_immediate_dir_externals(sbox
     'X/XE'              : Item(verb='Sending'),
   })
 
+  # Currently this fails because nothing is committed.
+  #
+  #   >svn st
+  #   X       X\XE
+  #   
+  #   Performing status on external item at 'X\XE':
+  #    M      C:\SVN\src-trunk\...\externals_tests-37\X\XE
+  #   M       C:\SVN\src-trunk\...\externals_tests-37\X\XE\alpha
+  #
+  #   >svn ci -m "m" --include-externals --depth immediates X
+  #
+  #   >
   actions.run_and_verify_commit(wc_dir, expected_output, expected_status,
     None, '--include-externals', '--depth=immediates', X)
 

Modified: subversion/branches/javahl-ra/subversion/tests/cmdline/import_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/tests/cmdline/import_tests.py?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/tests/cmdline/import_tests.py (original)
+++ subversion/branches/javahl-ra/subversion/tests/cmdline/import_tests.py Thu Dec 27 02:50:50 2012
@@ -469,8 +469,8 @@ def import_inherited_ignores(sbox):
 
   # Import the tree to ^/A/B/E.
   # We should never see any *.noo paths because those are blocked at the
-  # root of the repository by the svn:inheritable-ignores property.  Likewise
-  # *.doo paths are blocked by the svn:inheritable-ignores on ^/A/B.  Nor
+  # root of the repository by the svn:global-ignores property.  Likewise
+  # *.doo paths are blocked by the svn:global-ignores on ^/A/B.  Nor
   # should we see and *.boo or *.goo paths, as those are blocked by the
   # global-ignores config. Lastly, ^/A/B/E should not get any *.foo paths
   # because of the svn:ignore property on ^/A/B/E, but non-immediate children
@@ -517,7 +517,7 @@ def import_inherited_ignores(sbox):
   svntest.actions.run_and_verify_svn(None, expected_output, [], 'up', wc_dir)
 
   # Import the tree to ^/A/B/F with the --no-ignore option.
-  # Now only the ignores present in the svn:inheritable-ignores property
+  # Now only the ignores present in the svn:global-ignores property
   # should be considered.
   svntest.actions.run_and_verify_svn(None, None, [], 'import',
                                      '--config-dir', config_dir,

Modified: subversion/branches/javahl-ra/subversion/tests/cmdline/merge_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/tests/cmdline/merge_tests.py?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/tests/cmdline/merge_tests.py (original)
+++ subversion/branches/javahl-ra/subversion/tests/cmdline/merge_tests.py Thu Dec 27 02:50:50 2012
@@ -7611,7 +7611,7 @@ def merge_away_subtrees_noninheritable_r
   svntest.actions.run_and_verify_svn(None, None, [], 'up', wc_dir)
 
   # Merge r8 from A/D/H to A_COPY_D/H at depth empty.  Since r8 affects only
-  # A_COPY/D/H itself, the resulting mergeinfo is inheritabled.  Commit this
+  # A_COPY/D/H itself, the resulting mergeinfo is inheritable.  Commit this
   # merge as r13.
   expected_output = wc.State(H_COPY_2_path, {
     ''    : Item(status=' U'),

Modified: subversion/branches/javahl-ra/subversion/tests/cmdline/mergeinfo_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/tests/cmdline/mergeinfo_tests.py?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/tests/cmdline/mergeinfo_tests.py (original)
+++ subversion/branches/javahl-ra/subversion/tests/cmdline/mergeinfo_tests.py Thu Dec 27 02:50:50 2012
@@ -720,8 +720,8 @@ def natural_history_is_not_eligible_nor_
 # ranges as partially merged".
 @Issue(4050)
 @SkipUnless(server_has_mergeinfo)
-def noninheritabled_mergeinfo_not_always_eligible(sbox):
-  "noninheritabled mergeinfo not always eligible"
+def noninheritable_mergeinfo_not_always_eligible(sbox):
+  "noninheritable mergeinfo not always eligible"
 
   sbox.build()
   wc_dir = sbox.wc_dir
@@ -779,7 +779,7 @@ test_list = [ None,
               mergeinfo_on_pegged_wc_path,
               wc_target_inherits_mergeinfo_from_repos,
               natural_history_is_not_eligible_nor_merged,
-              noninheritabled_mergeinfo_not_always_eligible,
+              noninheritable_mergeinfo_not_always_eligible,
              ]
 
 if __name__ == '__main__':

Modified: subversion/branches/javahl-ra/subversion/tests/cmdline/prop_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/tests/cmdline/prop_tests.py?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/tests/cmdline/prop_tests.py (original)
+++ subversion/branches/javahl-ra/subversion/tests/cmdline/prop_tests.py Thu Dec 27 02:50:50 2012
@@ -2651,7 +2651,7 @@ def inheritable_ignores(sbox):
   os.chdir(saved_wd)
 
   # Now revert and try the add with the --no-ignore flag, only the
-  # svn:inheritable-ignores should be enforced.
+  # svn:global-ignores should be enforced.
   svntest.actions.run_and_verify_svn(None, None, [], 'revert', wc_dir, '-R')
   saved_wd = os.getcwd()
   os.chdir(sbox.wc_dir)

Modified: subversion/branches/javahl-ra/subversion/tests/cmdline/svntest/main.py
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/tests/cmdline/svntest/main.py?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================
--- subversion/branches/javahl-ra/subversion/tests/cmdline/svntest/main.py (original)
+++ subversion/branches/javahl-ra/subversion/tests/cmdline/svntest/main.py Thu Dec 27 02:50:50 2012
@@ -174,11 +174,11 @@ work_dir = "svn-test-work"
 # Constant for the merge info property.
 SVN_PROP_MERGEINFO = "svn:mergeinfo"
 
-# Constant for the inheritabled auto-props property.
-SVN_PROP_INHERITABLE_AUTOPROPS = "svn:inheritable-auto-props"
+# Constant for the inheritable auto-props property.
+SVN_PROP_INHERITABLE_AUTOPROPS = "svn:auto-props"
 
-# Constant for the inheritabled ignores property.
-SVN_PROP_INHERITABLE_IGNORES = "svn:inheritable-ignores"
+# Constant for the inheritable ignores property.
+SVN_PROP_INHERITABLE_IGNORES = "svn:global-ignores"
 
 # Where we want all the repositories and working copies to live.
 # Each test will have its own!
--- subversion/branches/javahl-ra/subversion/libsvn_client/client.h (original)
+++ subversion/branches/javahl-ra/subversion/libsvn_client/client.h Thu Dec 27 02:50:50 2012
@@ -351,11 +351,11 @@ svn_error_t *svn_client__get_paths_auto_
   apr_pool_t *scratch_pool);
 
 /* Gather all auto-props from CTX->config (or none if auto-props are
-   disabled) and all svn:inheritable-auto-props explicitly set on or inherited
+   disabled) and all svn:auto-props explicitly set on or inherited
    by PATH_OR_URL.
 
    If PATH_OR_URL is an unversioned WC path then gather the
-   svn:inheritable-auto-props inherited by PATH_OR_URL's nearest versioned
+   svn:auto-props inherited by PATH_OR_URL's nearest versioned
    parent.
 
    If PATH_OR_URL is a URL ask for the properties @HEAD, if it is a WC
@@ -366,10 +366,10 @@ svn_error_t *svn_client__get_paths_auto_
    names to const char *property values.
 
    If a given property name exists for the same pattern in both the config
-   file and in an a svn:inheritable-auto-props property, the latter overrides the
+   file and in an a svn:auto-props property, the latter overrides the
    former.  If a given property name exists for the same pattern in two
-   different inherited svn:inheritable-auto-props, then the closer path-wise
-   property overrides the more distant. svn:inheritable-auto-props explicitly set
+   different inherited svn:auto-props, then the closer path-wise
+   property overrides the more distant. svn:auto-props explicitly set
    on PATH_OR_URL have the highest precedence and override inherited props
    and config file settings.
 
@@ -383,7 +383,7 @@ svn_error_t *svn_client__get_all_auto_pr
 
 /* Get a combined list of ignore patterns from CTX->CONFIG, local ignore
    patterns on LOCAL_ABSPATH (per the svn:ignore property), and from any
-   svn:inheritable-ignores properties set on, or inherited by, LOCAL_ABSPATH.
+   svn:global-ignores properties set on, or inherited by, LOCAL_ABSPATH.
    If LOCAL_ABSPATH is unversioned but is located within a valid working copy,
    then find its nearest versioned parent path, if any, and return the ignore
    patterns for that parent.  Return an SVN_ERR_WC_NOT_WORKING_COPY error if
@@ -398,7 +398,7 @@ svn_error_t *svn_client__get_all_ignores
                                          apr_pool_t *result_pool,
                                          apr_pool_t *scratch_pool);
 
 /* Get a list of ignore patterns defined by the svn:inheritable-ignores
    properties set on, or inherited by, PATH_OR_URL.  Store the collected
    patterns as const char * elements in the array *IGNORES.  Allocate
    *IGNORES and its contents in RESULT_POOL.  Use  SCRATCH_POOL for
@@ -398,7 +398,7 @@ svn_error_t *svn_client__get_all_ignores
                                          apr_pool_t *scratch_pool);
 
-/* Get a list of ignore patterns defined by the svn:inheritable-ignores
+/* Get a list of ignore patterns defined by the svn:global-ignores
    properties set on, or inherited by, PATH_OR_URL.  Store the collected
    patterns as const char * elements in the array *IGNORES.  Allocate

Modified: subversion/branches/javahl-ra/subversion/libsvn_client/commit.c
URL: http://svn.apache.org/viewvc/subversion/branches/javahl-ra/subversion/libsvn_client/commit.c?rev=1426105&r1=1426104&r2=1426105&view=diff
==============================================================================